Skip to contents

This function calculates the fraction of converts with overlap for each cluster.

Usage

fraction_converts_with_overlap(cluster_overlap_df, isolate_lookup)

Arguments

cluster_overlap_df

A data frame with overlap information for isolate pairs. For more information, see cluster_isolate_overlap().

isolate_lookup

A lookup table for isolates and their clusters assignments which has other relevant epidemiological information. For more information, see get_isolate_lookup().

Value

A named vector with the fraction of converts with overlap for each cluster.