Calculate isolate-isolate overlap for clusters
Source:R/cluster_overlap.R
cluster_isolate_overlap.RdThis function considers every isolate in a cluster as a recipient, and returns if there is any overlap when other isolates in the cluster are the donors.
Arguments
- isolate_lookup
A lookup table for isolates and their clusters assignments which has other relevant epidemiological information. For more information, see
get_isolate_lookup().- iso_overlap_df
A data frame with overlap information for isolate pairs. For more information, see
isolate_isolate_overlap().