Categorize patients within clusters by epidemiological status
Source:R/cluster_categorize.R
cluster_patient_categorization.RdCategorizes each patient in a cluster based on their role in transmission:
index: admission positive, earliest isolate, isolate in cluster
multiply-colonized-index: admission positive, earliest isolate, isolate not in cluster
weak-index: not admission positive, but first surveillance is positive and in cluster
convert: had surveillance before first positive
adm-pos: first positive is in cluster and is first surveillance
adm-pos-convert: first positive is not in cluster but is first surveillance
secondary-convert: first positive is not in cluster and had prior surveillance
Arguments
- isolate_lookup
A lookup table from
get_isolate_lookup().- surv_df
A data frame with surveillance data (patient_id, genome_id, surv_date, result).