Calculate the fraction of converts with overlap
Source:R/cluster_overlap.R
fraction_converts_with_overlap.RdThis function calculates the fraction of converts with overlap for each cluster.
Arguments
- cluster_overlap_df
A data frame with overlap information for isolate pairs. For more information, see
cluster_isolate_overlap().- isolate_lookup
A lookup table for isolates and their clusters assignments which has other relevant epidemiological information. For more information, see
get_isolate_lookup().