Get non-single patient clusters from a vector of cluster assignments.
Source:R/cluster_utils.R
get_non_single_patient_clusters.RdThis function gets non-single patient clusters from a vector of cluster assignments.
Arguments
- isolate_lookup
A lookup table for isolates and their clusters assignments which has other relevant epidemiological information. For more information, see
get_isolate_lookup().