Perform clustering of isolates using a hard SNP distance cutoff.
Source:R/cluster_algorithms.R
get_tn_clusters_snp_thresh.RdThis function uses a hard SNP distance cutoff to define clusters naïvely, without using the phylogenetic tree.
Arguments
- snp_dist
A matrix of SNP distances between isolates constructed using a model of DNA evolution. See
get_snp_dist_matrix()for a useful function to generate this.- snp_thresh
A threshold for defining clusters.
- hclust_method
A string indicating the method to use for hierarchical clustering. See
stats::hclust()for more details. Default is "complete".