This function calculates the overlap between isolates in a given trace matrix.
Arguments
- isolate_lookup
A lookup table for isolates and their clusters assignments which has other relevant epidemiological information. For more information, see
get_isolate_lookup().- trace_mat
A matrix with rows representing days and columns representing patients.