Calculate isolate-isolate sequential overlap
Source:R/cluster_overlap.R
isolate_isolate_sequential_overlap.RdThis function calculates the sequential overlap between isolates in a given trace matrix. Sequential overlap counts the number of days where the recipient is at a location that the donor had previously been at (on a strictly earlier day), capturing potential indirect transmission via shared locations.
Arguments
- isolate_lookup
A lookup table for isolates and their clusters assignments which has other relevant epidemiological information. For more information, see
get_isolate_lookup().- trace_mat
A matrix with rows representing days and columns representing patients.